Tailon
======

Tailon is a self-hosted web application for looking at and searching
through log files. It is little more than a fancy web wrapper around
the following commands::

    tail -f
    tail -f | grep
    tail -f | awk
    tail -f | sed

Documentation:
    http://tailon.readthedocs.org/en/latest/

Development:
    https://github.com/gvalkov/tailon

Package:
    http://pypi.python.org/pypi/tailon

Changelog:
    http://tailon.readthedocs.org/en/latest/changelog.html
